==> move-within-2.9.57.tgz: package/README.md <==
Moves part of array within. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [moveWithin], [moveWithin$].<br>
> Similar: [copy], [copyWithin], [moveWithin].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.moveWithin(x, [j], [i], [I]);
// x: an array
// j: write index (0)
// i: read start index (0)
// I: read end index (end)
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 4, 5, 6];
array.moveWithin(x, 0, 1, 3);
// [ 2, 3, 1, 4, 5, 6 ] (2,3 to left)

array.moveWithin(x, 6, 3, 5);
// [ 1, 2, 3, 6, 4, 5 ] (4,5 to right)
```

### references

- [Array.prototype.copyWithin: MDN web docs](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/copyWithin)
- [immutable-iterable-prototype: @azu](https://github.com/azu/immutable-iterable-prototype)
- [array-move: @sindresorhus](https://www.npmjs.com/package/array-move)

[moveWithin]: https://github.com/nodef/extra-array/wiki/moveWithin
[moveWithin$]: https://github.com/nodef/extra-array/wiki/moveWithin$
[copy]: https://github.com/nodef/extra-array/wiki/copy
[copyWithin]: https://github.com/nodef/extra-array/wiki/copyWithin
[:running:]: https://npm.runkit.com/@extra-array/move-within
[:vhs:]: https://asciinema.org/a/342304
[:package:]: https://www.npmjs.com/package/@extra-array/move-within
[:moon:]: https://www.npmjs.com/package/@extra-array/move-within.min
[:ledger:]: https://unpkg.com/@extra-array/move-within/

==> move-within-2.10.1.tgz: package/README.md <==
Moves part of array within. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [moveWithin], [moveWithin$].<br>
> Similar: [copy], [copyWithin], [moveWithin].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.moveWithin(x, [j], [i], [I]);
// x: an array
// j: write index (0)
// i: read start index (0)
// I: read end index (X)
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 4, 5, 6];
array.moveWithin(x, 0, 1, 3);
// [ 2, 3, 1, 4, 5, 6 ] (2,3 to left)

array.moveWithin(x, 6, 3, 5);
// [ 1, 2, 3, 6, 4, 5 ] (4,5 to right)
```

### references

- [Array.prototype.copyWithin: MDN web docs](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/copyWithin)
- [immutable-iterable-prototype: @azu](https://github.com/azu/immutable-iterable-prototype)
- [array-move: @sindresorhus](https://www.npmjs.com/package/array-move)

[moveWithin]: https://github.com/nodef/extra-array/wiki/moveWithin
[moveWithin$]: https://github.com/nodef/extra-array/wiki/moveWithin$
[copy]: https://github.com/nodef/extra-array/wiki/copy
[copyWithin]: https://github.com/nodef/extra-array/wiki/copyWithin
[:running:]: https://npm.runkit.com/@extra-array/move-within
[:vhs:]: https://asciinema.org/a/342304
[:package:]: https://www.npmjs.com/package/@extra-array/move-within
[:moon:]: https://www.npmjs.com/package/@extra-array/move-within.min
[:ledger:]: https://unpkg.com/@extra-array/move-within/
